Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(356)

Unified Diff: chrome/browser/browser.h

Issue 329004: Mac: enable History, Downloads, and Open Location... with no windows open. (Closed)
Patch Set: Merged ToT. Created 11 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/app_controller_mac.mm ('k') | chrome/browser/browser.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/browser.h
diff --git a/chrome/browser/browser.h b/chrome/browser/browser.h
index a6c15c2848a80cc7f598b2c1275adf1b26a27780..2372f9542df82d87c7e8bf845d70bc8dbefe4930 100644
--- a/chrome/browser/browser.h
+++ b/chrome/browser/browser.h
@@ -168,7 +168,10 @@ class Browser : public TabStripModelDelegate,
static void OpenApplicationWindow(Profile* profile, const GURL& url);
#if defined(OS_MACOSX)
- // Open a new window with help (needed on Mac when there are no windows).
+ // Open a new window with history/downloads/help (needed on Mac when there are
+ // no windows).
+ static void OpenHistoryWindow(Profile* profile);
+ static void OpenDownloadsWindow(Profile* profile);
static void OpenHelpWindow(Profile* profile);
#endif
« no previous file with comments | « chrome/browser/app_controller_mac.mm ('k') | chrome/browser/browser.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698